ButtonLoaderData class

Constructors

ButtonLoaderData({ButtonStyle materialButtonStyle = const ButtonStyle(), ButtonStyle fluentButtonStyle = const fluent.ButtonStyle(), MacosButtonStyle macosButtonStyle = const MacosButtonStyle(), CupertinoButtonStyle cupertinoButtonStyle = const CupertinoButtonStyle(), Key? buttonKey, double borderRadius = 15, bool autofocus = false, FocusNode? focusNode, bool useFluentUi = false, bool useMacUi = false, ButtonLoader buttonLoader = const ButtonLoader(), double? buttonHeight, double? buttonWidth})
const

Properties

autofocus → bool
not available in cupertino
final
borderRadius → double
Add border radius for button and the same for loader
final
buttonHeight → double?
button height for idle state
final
buttonKey → Key?
Add key for button for test
final
buttonLoader → ButtonLoader
Custom Button Loader and can custom success or error widget
final
buttonWidth → double?
button width for idle state
final
cupertinoButtonStyle → CupertinoButtonStyle
style button in cupertino app
final
fluentButtonStyle → ButtonStyle
style button in fluent ui app need use fluent ui package
final
focusNode → FocusNode?
not available in cupertino
final
hashCode → int
The hash code for this object.
no setterinherited
macosButtonStyle → MacosButtonStyle
style button in macos ui app need macos ui package
final
materialButtonStyle → ButtonStyle
style button in material app
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useFluentUi → bool
for use fluent ui button from fluent ui package
final
useMacUi → bool
for use macos ui button from macos ui package
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited