MacosButtonStyle class

Inheritance

Constructors

MacosButtonStyle({ButtonSize buttonSize = macos.ButtonSize.large, AlignmentGeometry alignment = Alignment.center, Color? color, double pressedOpacity = 0.4, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8.0)), Color disabledColor = cup.CupertinoColors.quaternarySystemFill, bool isSecondary = false, MouseCursor mouseCursor = SystemMouseCursors.basic, EdgeInsetsGeometry? padding, String? semanticLabel})
const

Properties

alignment → AlignmentGeometry
finalinherited
borderRadius → BorderRadius
finalinherited
buttonSize → ButtonSize
final
color → Color?
final
disabledColor → Color
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isSecondary → bool
final
minSize → double?
finalinherited
mouseCursor → MouseCursor
final
padding → EdgeInsetsGeometry?
final
pressedOpacity → double
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited